@@ -182,6 +182,36 @@ class Style:
         self.__name =  chr(self.__column+64)+str(self.__row)
         return None
 
+class Data:
+    """
+    Documentation
+    """
+
+    def __init__(self):
+        """
+        Documentation
+        """
+        self.__variables = {}
+        self.__table = []
+
+    @property
+    def array(self):
+        """
+        Documentation
+        """
+        return self.__variables
+
+    def add(self, key, value):
+        """
+        Documentation
+        """
+        if 'tbl_' in key:
+            self.__table.append({key:value})
+            self.__variables.update({'table':self.__table})
+        else:
+            self.__variables.update({key:value})
+        return None
+
 class Model:
     """
     Documentation
@@ -240,6 +270,8 @@ class Model:
         for range in self.__worksheet.merged_cells.ranges:
             self.__mergedcells.append(Variable(str(range), None, None, range))
 
+        self.__data = Data()
+
     @property
     def rows(self):
         """
@@ -373,7 +405,15 @@ class Model:
             rows_height.append([row.name, row.value])
         return rows_height
 
-    def sizetables(self, data):
+    @property
+    def data(self):
+        """
+        Documentation
+        """
+        return self.__data.array
+
+    @property
+    def sizetables(self):
         """
         Documentation
         """
@@ -387,7 +427,7 @@ class Model:
         for name in self.variablenames:
             if 'tbl' in name:
                 n = 0
-                for tbl in data['table']:
+                for tbl in self.data['table']:
                     for key in tbl:
                         if name == key:
                             n += 1
@@ -401,12 +441,12 @@ class Model:
             result.append([int(key.split(':')[0]),int(key.split(':')[1])])
         return result
 
-    def update(self, sizetables):
+    def restyle(self):
         """
         Documentation
         """
-        self.remerge(sizetables)
-        for sizetable in sizetables:
+        self.remerge(self.sizetables)
+        for sizetable in self.sizetables:
             self.rows = self.rows + sizetable[1]
             for variable in self.variables:
                 if variable.row > sizetable[0]:
@@ -418,13 +458,13 @@ class Model:
                 if row_height.row > sizetable[0]:
                     row_height.row = row_height.row + sizetable[1]
         rows_height = self.__rows_height
-        for sizetable in sizetables:
+        for sizetable in self.sizetables:
             for row_height in rows_height:
                  if row_height.row == sizetable[0]:
                      for n in range(sizetable[1]-1):
                          self.__rows_height.append(Variable(row_height.name+n+1,row_height.row+n+1,row_height.column,row_height.value))
         styles = self.styles
-        for sizetable in sizetables:
+        for sizetable in self.sizetables:
             for style in styles:
                 if style.row == sizetable[0]:
                     for n in range(sizetable[1]-1):
@@ -433,24 +473,25 @@ class Model:
             style.rename()
         return None
 
-    def data(self, data):
+    def update(self, data):
         """
         Documentation
         """
-
+        self.__data = data
+        self.restyle()
         for variable in self.variables:
-            if variable.name in data:
-                variable.value = data[variable.name]
-            elif 'table' in data:
-                for table in data['table']:
+            if variable.name in self.data:
+                variable.value = self.data[variable.name]
+            elif 'table' in self.data:
+                for table in self.data['table']:
                     if variable.name in table and variable.value == None:
                         variable.value = table[variable.name]
                         table.popitem()
         variables = self.variables
         for variable in variables:
-            if 'table' in data:
+            if 'table' in self.data:
                 n=0
-                for table in data['table']:
+                for table in self.data['table']:
                     if variable.name in table:
                         n=n+1
                         self.__variables.append(Variable(variable.name+str(n),variable.row+n,variable.column,table[variable.name]))
@@ -465,7 +506,12 @@ class Model:
         for row in self.rows_height:
             worksheet.row_dimensions[row[0]].height = row[1]
         for variable in self.variables:
-            worksheet.cell(variable.row, variable.column, variable.value)
+            if 'img_' in variable.name:
+                img = openpyxl.drawing.image.Image(variable.value)
+                img.anchor = worksheet.cell(variable.row, variable.column).coordinate
+                worksheet.add_image(img)
+            else:
+                worksheet.cell(variable.row, variable.column, variable.value)
         for style in self.styles:
             #worksheet[style.name].data_type = copy(style.data_type)
             worksheet[style.name].font = copy(style.font)
